==> aws-cdk-lib-2.0.0-rc.6-sources.jar: software/amazon/awscdk/services/sagemaker/CfnNotebookInstanceLifecycleConfigProps.java <==
package software.amazon.awscdk.services.sagemaker;

/**
 * Properties for defining a `AWS::SageMaker::NotebookInstanceLifecycleConfig`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-06-02T09:55:47.977Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_sagemaker.CfnNotebookInstanceLifecycleConfigProps")
@software.amazon.jsii.Jsii.Proxy(CfnNotebookInstanceLifecycleConfigProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnNotebookInstanceLifecycleConfigProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::SageMaker::NotebookInstanceLifecycleConfig.NotebookInstanceLifecycleConfigName`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getNotebookInstanceLifecycleConfigName() {
        return null;
    }

    /**
     * `AWS::SageMaker::NotebookInstanceLifecycleConfig.OnCreate`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getOnCreate() {
        return null;
    }

    /**
     * `AWS::SageMaker::NotebookInstanceLifecycleConfig.OnStart`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getOnStart() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnNotebookInstanceLifecycleConfigProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnNotebookInstanceLifecycleConfigProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnNotebookInstanceLifecycleConfigProps> {
        private java.lang.String notebookInstanceLifecycleConfigName;
        private java.lang.Object onCreate;
        private java.lang.Object onStart;

        /**
         * Sets the value of {@link CfnNotebookInstanceLifecycleConfigProps#getNotebookInstanceLifecycleConfigName}
         * @param notebookInstanceLifecycleConfigName `AWS::SageMaker::NotebookInstanceLifecycleConfig.NotebookInstanceLifecycleConfigName`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder notebookInstanceLifecycleConfigName(java.lang.String notebookInstanceLifecycleConfigName) {
            this.notebookInstanceLifecycleConfigName = notebookInstanceLifecycleConfigName;
            return this;
        }

        /**
         * Sets the value of {@link CfnNotebookInstanceLifecycleConfigProps#getOnCreate}
         * @param onCreate `AWS::SageMaker::NotebookInstanceLifecycleConfig.OnCreate`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder onCreate(software.amazon.awscdk.IResolvable onCreate) {
            this.onCreate = onCreate;
            return this;
        }

        /**
         * Sets the value of {@link CfnNotebookInstanceLifecycleConfigProps#getOnCreate}
         * @param onCreate `AWS::SageMaker::NotebookInstanceLifecycleConfig.OnCreate`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder onCreate(java.util.List<? extends java.lang.Object> onCreate) {
            this.onCreate = onCreate;
            return this;
        }

        /**
         * Sets the value of {@link CfnNotebookInstanceLifecycleConfigProps#getOnStart}
         * @param onStart `AWS::SageMaker::NotebookInstanceLifecycleConfig.OnStart`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder onStart(software.amazon.awscdk.IResolvable onStart) {
            this.onStart = onStart;
            return this;
        }

        /**
         * Sets the value of {@link CfnNotebookInstanceLifecycleConfigProps#getOnStart}
         * @param onStart `AWS::SageMaker::NotebookInstanceLifecycleConfig.OnStart`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder onStart(java.util.List<? extends java.lang.Object> onStart) {
            this.onStart = onStart;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnNotebookInstanceLifecycleConfigProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnNotebookInstanceLifecycleConfigProps build() {
            return new Jsii$Proxy(notebookInstanceLifecycleConfigName, onCreate, onStart);
        }
    }

    /**
     * An implementation for {@link CfnNotebookInstanceLifecycleConfigProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnNotebookInstanceLifecycleConfigProps {
        private final java.lang.String notebookInstanceLifecycleConfigName;
        private final java.lang.Object onCreate;
        private final java.lang.Object onStart;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.notebookInstanceLifecycleConfigName = software.amazon.jsii.Kernel.get(this, "notebookInstanceLifecycleConfigName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.onCreate = software.amazon.jsii.Kernel.get(this, "onCreate", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.onStart = software.amazon.jsii.Kernel.get(this, "onStart", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String notebookInstanceLifecycleConfigName, final java.lang.Object onCreate, final java.lang.Object onStart) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.notebookInstanceLifecycleConfigName = notebookInstanceLifecycleConfigName;
            this.onCreate = onCreate;
            this.onStart = onStart;
        }

        @Override
        public final java.lang.String getNotebookInstanceLifecycleConfigName() {
            return this.notebookInstanceLifecycleConfigName;
        }

        @Override
        public final java.lang.Object getOnCreate() {
            return this.onCreate;
        }

        @Override
        public final java.lang.Object getOnStart() {
            return this.onStart;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getNotebookInstanceLifecycleConfigName() != null) {
                data.set("notebookInstanceLifecycleConfigName", om.valueToTree(this.getNotebookInstanceLifecycleConfigName()));
            }
            if (this.getOnCreate() != null) {
                data.set("onCreate", om.valueToTree(this.getOnCreate()));
            }
            if (this.getOnStart() != null) {
                data.set("onStart", om.valueToTree(this.getOnStart()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_sagemaker.CfnNotebookInstanceLifecycleConfigProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnNotebookInstanceLifecycleConfigProps.Jsii$Proxy that = (CfnNotebookInstanceLifecycleConfigProps.Jsii$Proxy) o;

            if (this.notebookInstanceLifecycleConfigName != null ? !this.notebookInstanceLifecycleConfigName.equals(that.notebookInstanceLifecycleConfigName) : that.notebookInstanceLifecycleConfigName != null) return false;
            if (this.onCreate != null ? !this.onCreate.equals(that.onCreate) : that.onCreate != null) return false;
            return this.onStart != null ? this.onStart.equals(that.onStart) : that.onStart == null;
        }

        @Override
        public final int hashCode() {
            int result = this.notebookInstanceLifecycleConfigName != null ? this.notebookInstanceLifecycleConfigName.hashCode() : 0;
            result = 31 * result + (this.onCreate != null ? this.onCreate.hashCode() : 0);
            result = 31 * result + (this.onStart != null ? this.onStart.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/sagemaker/CfnNotebookInstanceLifecycleConfigProps.java <==
package software.amazon.awscdk.services.sagemaker;

/**
 * Properties for defining a `CfnNotebookInstanceLifecycleConfig`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.sagemaker.*;
 * CfnNotebookInstanceLifecycleConfigProps cfnNotebookInstanceLifecycleConfigProps = CfnNotebookInstanceLifecycleConfigProps.builder()
 *         .notebookInstanceLifecycleConfigName("notebookInstanceLifecycleConfigName")
 *         .onCreate(List.of(NotebookInstanceLifecycleHookProperty.builder()
 *                 .content("content")
 *                 .build()))
 *         .onStart(List.of(NotebookInstanceLifecycleHookProperty.builder()
 *                 .content("content")
 *                 .build()))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:12.704Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_sagemaker.CfnNotebookInstanceLifecycleConfigProps")
@software.amazon.jsii.Jsii.Proxy(CfnNotebookInstanceLifecycleConfigProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnNotebookInstanceLifecycleConfigProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name of the lifecycle configuration.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getNotebookInstanceLifecycleConfigName() {
        return null;
    }

    /**
     * A shell script that runs only once, when you create a notebook instance.
     * <p>
     * The shell script must be a base64-encoded string.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getOnCreate() {
        return null;
    }

    /**
     * A shell script that runs every time you start a notebook instance, including when you create the notebook instance.
     * <p>
     * The shell script must be a base64-encoded string.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getOnStart() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnNotebookInstanceLifecycleConfigProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnNotebookInstanceLifecycleConfigProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnNotebookInstanceLifecycleConfigProps> {
        java.lang.String notebookInstanceLifecycleConfigName;
        java.lang.Object onCreate;
        java.lang.Object onStart;

        /**
         * Sets the value of {@link CfnNotebookInstanceLifecycleConfigProps#getNotebookInstanceLifecycleConfigName}
         * @param notebookInstanceLifecycleConfigName The name of the lifecycle configuration.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder notebookInstanceLifecycleConfigName(java.lang.String notebookInstanceLifecycleConfigName) {
            this.notebookInstanceLifecycleConfigName = notebookInstanceLifecycleConfigName;
            return this;
        }

        /**
         * Sets the value of {@link CfnNotebookInstanceLifecycleConfigProps#getOnCreate}
         * @param onCreate A shell script that runs only once, when you create a notebook instance.
         *                 The shell script must be a base64-encoded string.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder onCreate(software.amazon.awscdk.IResolvable onCreate) {
            this.onCreate = onCreate;
            return this;
        }

        /**
         * Sets the value of {@link CfnNotebookInstanceLifecycleConfigProps#getOnCreate}
         * @param onCreate A shell script that runs only once, when you create a notebook instance.
         *                 The shell script must be a base64-encoded string.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder onCreate(java.util.List<? extends java.lang.Object> onCreate) {
            this.onCreate = onCreate;
            return this;
        }

        /**
         * Sets the value of {@link CfnNotebookInstanceLifecycleConfigProps#getOnStart}
         * @param onStart A shell script that runs every time you start a notebook instance, including when you create the notebook instance.
         *                The shell script must be a base64-encoded string.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder onStart(software.amazon.awscdk.IResolvable onStart) {
            this.onStart = onStart;
            return this;
        }

        /**
         * Sets the value of {@link CfnNotebookInstanceLifecycleConfigProps#getOnStart}
         * @param onStart A shell script that runs every time you start a notebook instance, including when you create the notebook instance.
         *                The shell script must be a base64-encoded string.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder onStart(java.util.List<? extends java.lang.Object> onStart) {
            this.onStart = onStart;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnNotebookInstanceLifecycleConfigProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnNotebookInstanceLifecycleConfigProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnNotebookInstanceLifecycleConfigProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnNotebookInstanceLifecycleConfigProps {
        private final java.lang.String notebookInstanceLifecycleConfigName;
        private final java.lang.Object onCreate;
        private final java.lang.Object onStart;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.notebookInstanceLifecycleConfigName = software.amazon.jsii.Kernel.get(this, "notebookInstanceLifecycleConfigName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.onCreate = software.amazon.jsii.Kernel.get(this, "onCreate", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.onStart = software.amazon.jsii.Kernel.get(this, "onStart", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.notebookInstanceLifecycleConfigName = builder.notebookInstanceLifecycleConfigName;
            this.onCreate = builder.onCreate;
            this.onStart = builder.onStart;
        }

        @Override
        public final java.lang.String getNotebookInstanceLifecycleConfigName() {
            return this.notebookInstanceLifecycleConfigName;
        }

        @Override
        public final java.lang.Object getOnCreate() {
            return this.onCreate;
        }

        @Override
        public final java.lang.Object getOnStart() {
            return this.onStart;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getNotebookInstanceLifecycleConfigName() != null) {
                data.set("notebookInstanceLifecycleConfigName", om.valueToTree(this.getNotebookInstanceLifecycleConfigName()));
            }
            if (this.getOnCreate() != null) {
                data.set("onCreate", om.valueToTree(this.getOnCreate()));
            }
            if (this.getOnStart() != null) {
                data.set("onStart", om.valueToTree(this.getOnStart()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_sagemaker.CfnNotebookInstanceLifecycleConfigProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnNotebookInstanceLifecycleConfigProps.Jsii$Proxy that = (CfnNotebookInstanceLifecycleConfigProps.Jsii$Proxy) o;

            if (this.notebookInstanceLifecycleConfigName != null ? !this.notebookInstanceLifecycleConfigName.equals(that.notebookInstanceLifecycleConfigName) : that.notebookInstanceLifecycleConfigName != null) return false;
            if (this.onCreate != null ? !this.onCreate.equals(that.onCreate) : that.onCreate != null) return false;
            return this.onStart != null ? this.onStart.equals(that.onStart) : that.onStart == null;
        }

        @Override
        public final int hashCode() {
            int result = this.notebookInstanceLifecycleConfigName != null ? this.notebookInstanceLifecycleConfigName.hashCode() : 0;
            result = 31 * result + (this.onCreate != null ? this.onCreate.hashCode() : 0);
            result = 31 * result + (this.onStart != null ? this.onStart.hashCode() : 0);
            return result;
        }
    }
}
